@@ -54,6 +54,8 @@ $string['availabletodatevalidation'] = 'The available to date cannot be before t
 $string['blank'] = 'Blank';
 $string['buttons'] = 'Actions';
 $string['bynameondate'] = 'by {$a->name} - {$a->date}';
+$string['calendarend'] = '{$a} closes';
+$string['calendarstart'] = '{$a} opens';
 $string['cancel'] = 'Cancel';
 $string['cannotaccesspresentsother'] = 'You are not allowed to access presets from other users';
 $string['cannotadd'] = 'Can not add entries!';
@@ -68,6 +70,9 @@ $string['comments'] = 'Comments';
 $string['commentsaved'] = 'Comment saved';
 $string['commentsn'] = '{$a} comment(s)';
 $string['commentsoff'] = 'Comments feature is not enabled';
+$string['completionentries'] = 'Require entries';
+$string['completionentriescount'] = 'Count of entries';
+$string['completionentriesdesc'] = 'Minimum number of entries required: {$a}';
 $string['configenablerssfeeds'] = 'This switch will enable the possibility of RSS feeds for all databases. You will still need to turn feeds on manually in the settings for each database.';
 $string['confirmdeletefield'] = 'You are about to delete this field, are you sure?';
 $string['confirmdeleterecord'] = 'Are you sure you want to delete this entry?';
@@ -97,6 +102,7 @@ $string['data:viewanyrating'] = 'View total ratings that anyone received';
 $string['data:viewentry'] = 'View entries';
 $string['data:viewrating'] = 'View the total rating you received';
 $string['data:writeentry'] = 'Write entries';
+$string['data:view'] = 'View database activity';
 $string['date'] = 'Date';
 $string['dateentered'] = 'Date entered';
 $string['defaultfielddelimiter'] = '(default is the comma character)';
@@ -121,6 +127,7 @@ $string['editordisable'] = 'Disable editor';
 $string['editorenable'] = 'Enable editor';
 $string['emptyadd'] = 'The Add template is empty, generating a default form...';
 $string['emptyaddform'] = 'You did not fill out any fields!';
+$string['enabletemplateeditorcheck'] = 'Are you sure you want to enable the editor? This may result in content being altered when the template is saved.';
 $string['eventfieldcreated'] = 'Field created';
 $string['eventfielddeleted'] = 'Field deleted';
 $string['eventfieldupdated'] = 'Field updated';
@@ -194,8 +201,13 @@ $string['expired'] = 'Sorry, this activity closed on {$a} and is no longer avail
 $string['importentries'] = 'Import entries';
 $string['importsuccess'] = 'The preset has been successfully applied.';
 $string['includeapproval'] = 'Include approval status';
+$string['includetags'] = 'Include tags';
 $string['includetime'] = 'Include time added/modified';
 $string['includeuserdetails'] = 'Include user details';
+$string['indicator:cognitivedepth'] = 'Database cognitive';
+$string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Database activity.';
+$string['indicator:socialbreadth'] = 'Database social';
+$string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Database activity.';
 $string['insufficiententries'] = 'more entries needed to view this database';
 $string['intro'] = 'Description';
 $string['invalidaccess'] = 'This page was not accessed correctly';
@@ -250,18 +262,6 @@ $string['movezipfailed'] = 'Can\'t move zip';
 $string['multientry'] = 'Repeated entry';
 $string['multimenu'] = 'Menu (Multi-select)';
 $string['multipletags'] = 'Multiple tags found! Template not saved';
-$string['namedate'] = 'Date field';
-$string['namefile'] = 'File field';
-$string['namecheckbox'] = 'Checkbox field';
-$string['namelatlong'] = 'Latitude/longitude field';
-$string['namemenu'] = 'Menu field';
-$string['namemultimenu'] = 'Multiple-selection menu field';
-$string['namenumber'] = 'Number field';
-$string['namepicture'] = 'Picture field';
-$string['nameradiobutton'] = 'Radio button field';
-$string['nametext'] = 'Text field';
-$string['nametextarea'] = 'Textarea field';
-$string['nameurl'] = 'URL field';
 $string['newentry'] = 'New entry';
 $string['newfield'] = 'Create a new field';
 $string['newfield_help'] = 'A field allows the input of data. Each entry in a database activity can have multiple fields of multiple types such as a date field, which allows participants to select a day, month and year from a dropdown list, a picture field, which allows participants to upload an image file, or a checkbox field, which allows participants to select one or more options.
@@ -300,17 +300,40 @@ $string['pluginname'] = 'Database';
 $string['portfolionotfile'] = 'Export to a portfolio rather than a file (csv and leap2a only)';
 $string['presetinfo'] = 'Saving as a preset will publish this template. Other users may be able to use it in their databases.';
 $string['presets'] = 'Presets';
+$string['privacy:metadata:commentpurpose'] = 'Comments on database records';
+$string['privacy:metadata:data_content'] = 'Represents one answer to one field in database activity module';
+$string['privacy:metadata:data_content:fieldid'] = 'Field definition id';
+$string['privacy:metadata:data_content:content'] = 'Content';
+$string['privacy:metadata:data_content:content1'] = 'Additional content 1';
+$string['privacy:metadata:data_content:content2'] = 'Additional content 2';
+$string['privacy:metadata:data_content:content3'] = 'Additional content 3';
+$string['privacy:metadata:data_content:content4'] = 'Additional content 4';
+$string['privacy:metadata:data_records'] = 'Represent records in database acitivity module';
+$string['privacy:metadata:data_records:userid'] = 'User who created the record';
+$string['privacy:metadata:data_records:groupid'] = 'Group';
+$string['privacy:metadata:data_records:timecreated'] = 'Time when record was created';
+$string['privacy:metadata:data_records:timemodified'] = 'Time when record was last modified';
+$string['privacy:metadata:data_records:approved'] = 'Approval status';
+$string['privacy:metadata:datafieldnpluginsummary'] = 'Fields for database activity module';
+$string['privacy:metadata:filepurpose'] = 'File attached to the database record';
+$string['privacy:metadata:tagpurpose'] = 'Tags on database records';
+$string['privacy:metadata:ratingpurpose'] = 'Ratings on database records';
 $string['radiobutton'] = 'Radio buttons';
 $string['recordapproved'] = 'Entry approved';
 $string['recorddeleted'] = 'Entry deleted';
 $string['recorddisapproved'] = 'Entry unapproved';
 $string['recordsnotsaved'] = 'No entry was saved. Please check the format of the uploaded file.';
 $string['recordssaved'] = 'entries saved';
+$string['removealldatatags'] = 'Remove all database tags';
 $string['requireapproval'] = 'Approval required';
 $string['requireapproval_help'] = 'If enabled, entries require approving by a teacher before they are viewable by everyone.';
 $string['required'] = 'Required';
-$string['requiredentries'] = 'Entries required for completion';
-$string['requiredentries_help'] = 'The number of entries a student is required to submit before the activity can be considered complete.';
+$string['requiredentries'] = 'Entries required for completion (old)';
+$string['requiredentries_help'] = "If set, a message is displayed stating the number of entries required for completion. Note that this setting is not connected to activity completion.
+
+For entries required for activity completion, the new Activity completion setting 'Require entries' should be used. To remove this setting completely, set to none, then save changes.
+Please use the Entries required fields in the Activity completion section instead.";
+$string['requiredentrieswarning'] = 'This setting has been replaced by an Activity completion setting "Require entries"';
 $string['requiredentriestoview'] = 'Entries required before viewing';
 $string['requiredentriestoview_help'] = 'The number of entries a student is required to submit before they can view entries from other students.
 
@@ -332,6 +355,8 @@ $string['savesettings'] = 'Save settings';
 $string['savesuccess'] = 'Saved successfully. Your preset will now be available across the site.';
 $string['savetemplate'] = 'Save template';
 $string['search'] = 'Search';
+$string['search:activity'] = 'Database - activity information';
+$string['search:entry'] = 'Database - entries';
 $string['selectedrequired'] = 'All selected required';
 $string['showall'] = 'Show all entries';
 $string['single'] = 'View single';
@@ -340,6 +365,9 @@ $string['subplugintype_datafield'] = 'Database field type';
 $string['subplugintype_datafield_plural'] = 'Database field types';
 $string['subplugintype_datapreset'] = 'Preset';
 $string['subplugintype_datapreset_plural'] = 'Presets';
+$string['tagarea_data_records'] = 'Data records';
+$string['tags'] = 'Tags';
+$string['tagsdeleted'] = 'Database tags have been deleted';
 $string['teachersandstudents'] = '{$a->teachers} and {$a->students}';
 $string['templates'] = 'Templates';
 $string['templatesaved'] = 'Template saved';
@@ -370,3 +398,17 @@ $string['viewfromdate'] = 'Read only from';
 $string['viewtodate'] = 'Read only to';
 $string['viewtodatevalidation'] = 'The read only to date cannot be before the read only from date.';
 $string['wrongdataid'] = 'Wrong data id provided';
+
+// Deprecated since Moodle 3.2.
+$string['namedate'] = 'Date field';
+$string['namefile'] = 'File field';
+$string['namecheckbox'] = 'Checkbox field';
+$string['namelatlong'] = 'Latitude/longitude field';
+$string['namemenu'] = 'Menu field';
+$string['namemultimenu'] = 'Multiple-selection menu field';
+$string['namenumber'] = 'Number field';
+$string['namepicture'] = 'Picture field';
+$string['nameradiobutton'] = 'Radio button field';
+$string['nametext'] = 'Text field';
+$string['nametextarea'] = 'Textarea field';
+$string['nameurl'] = 'URL field';
