@@ -22,7 +22,7 @@
  * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
 
-$string['add_item'] = 'Add question to activity';
+$string['add_item'] = 'Add question';
 $string['add_pagebreak'] = 'Add a page break';
 $string['adjustment'] = 'Adjustment';
 $string['after_submit'] = 'After submission';
@@ -30,36 +30,39 @@ $string['allowfullanonymous'] = 'Allow full anonymous';
 $string['analysis'] = 'Analysis';
 $string['anonymous'] = 'Anonymous';
 $string['anonymous_edit'] = 'Record user names';
-$string['anonymous_entries'] = 'Anonymous entries';
+$string['anonymous_entries'] = 'Anonymous entries ({$a})';
 $string['anonymous_user'] = 'Anonymous user';
+$string['answerquestions'] = 'Answer the questions';
 $string['append_new_items'] = 'Append new items';
 $string['autonumbering'] = 'Auto number questions';
 $string['autonumbering_help'] = 'Enables or disables automated numbers for each question';
 $string['average'] = 'Average';
 $string['bold'] = 'Bold';
-$string['cancel_moving'] = 'Cancel moving';
+$string['calendarend'] = '{$a} closes';
+$string['calendarstart'] = '{$a} opens';
 $string['cannotaccess'] = 'You can only access this feedback from a course';
-$string['cannotmapfeedback'] = 'Database problem, unable to map feedback to course';
 $string['cannotsavetempl'] = 'saving templates is not allowed';
-$string['cannotunmap'] = 'Database problem, unable to unmap';
 $string['captcha'] = 'Captcha';
 $string['captchanotset'] = 'Captcha hasn\'t been set.';
 $string['closebeforeopen'] = 'You have specified an end date before the start date.';
 $string['completed_feedbacks'] = 'Submitted answers';
 $string['complete_the_form'] = 'Answer the questions...';
+$string['completed'] = 'Completed';
+$string['completedon'] = 'Completed on {$a}';
 $string['completionsubmit'] = 'View as completed if the feedback is submitted';
 $string['configallowfullanonymous'] = 'If set to \'yes\', users can complete a feedback activity on the front page without being required to log in.';
 $string['confirmdeleteentry'] = 'Are you sure you want to delete this entry?';
 $string['confirmdeleteitem'] = 'Are you sure you want to delete this element?';
 $string['confirmdeletetemplate'] = 'Are you sure you want to delete this template?';
 $string['confirmusetemplate'] = 'Are you sure you want to use this template?';
-$string['continue_the_form'] = 'Continue the form';
+$string['continue_the_form'] = 'Continue answering the questions...';
 $string['count_of_nums'] = 'Count of numbers';
 $string['courseid'] = 'courseid';
 $string['creating_templates'] = 'Save these questions as a new template';
 $string['delete_entry'] = 'Delete entry';
 $string['delete_item'] = 'Delete question';
 $string['delete_old_items'] = 'Delete old items';
+$string['delete_pagebreak'] = 'Delete page break';
 $string['delete_template'] = 'Delete template';
 $string['delete_templates'] = 'Delete template...';
 $string['depending'] = 'Dependencies';
@@ -132,9 +135,14 @@ $string['checkbox'] = 'Multiple choice - multiple answers allowed (check boxes)'
 $string['check_values'] = 'Possible responses';
 $string['choosefile'] = 'Choose a file';
 $string['chosen_feedback_response'] = 'chosen feedback response';
+$string['downloadresponseas'] = 'Download all responses as:';
 $string['importfromthisfile'] = 'Import from this file';
 $string['import_questions'] = 'Import questions';
 $string['import_successfully'] = 'Import successfully';
+$string['indicator:cognitivedepth'] = 'Feedback cognitive';
+$string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Feedback activity.';
+$string['indicator:socialbreadth'] = 'Feedback social';
+$string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Feedback activity.';
 $string['info'] = 'Information';
 $string['infotype'] = 'Information type';
 $string['insufficient_responses_for_this_group'] = 'There are insufficient responses for this group';
@@ -143,18 +151,17 @@ $string['insufficient_responses_help'] = 'For the feedback to be anonymous, ther
 $string['item_label'] = 'Label';
 $string['item_name'] = 'Question';
 $string['label'] = 'Label';
-$string['line_values'] = 'Rating';
+$string['labelcontents'] = 'Contents';
 $string['mapcourseinfo'] = 'This is a site-wide feedback that is available to all courses using the feedback block. You can however limit the courses to which it will appear by mapping them. Search the course and map it to this feedback.';
 $string['mapcoursenone'] = 'No courses mapped. Feedback available to all courses';
 $string['mapcourse'] = 'Map feedback to courses';
 $string['mapcourse_help'] = 'By default, feedback forms created on your homepage are available site-wide
 and will appear in all courses using the feedback block. You can force the feedback form to appear by making it a sticky block or limit the courses in which a feedback form will appear by mapping it to specific courses.';
 $string['mapcourses'] = 'Map feedback to courses';
-$string['mapcourses_help'] = 'Once you have selected the relevant course(s) from your search,
-you can associate them with this feedback using map course(s). Multiple courses may be selected by holding down the Apple or Ctrl key whilst clicking on the course names. A course may be disassociated from a feedback at any time.';
 $string['mappedcourses'] = 'Mapped courses';
-$string['max_args_exceeded'] = 'Max 6 arguments can be handled, too many arguments for';
-$string['maximal'] = 'maximal';
+$string['mappingchanged'] = 'Course mapping has been changed';
+$string['minimal'] = 'minimum';
+$string['maximal'] = 'maximum';
 $string['messageprovider:message'] = 'Feedback reminder';
 $string['messageprovider:submission'] = 'Feedback notifications';
 $string['mode'] = 'Mode';
@@ -171,10 +178,7 @@ Feedback activities may be used
 * For anti-bullying surveys in which students can report incidents anonymously';
 $string['modulename_link'] = 'mod/feedback/view';
 $string['modulenameplural'] = 'Feedback';
-$string['movedown_item'] = 'Move this question down';
-$string['move_here'] = 'Move here';
 $string['move_item'] = 'Move this question';
-$string['moveup_item'] = 'Move this question up';
 $string['multichoice'] = 'Multiple choice';
 $string['multichoicerated'] = 'Multiple choice (rated)';
 $string['multichoicetype'] = 'Multiple choice type';
@@ -189,13 +193,13 @@ $string['no_itemlabel'] = 'No label';
 $string['no_itemname'] = 'No itemname';
 $string['no_items_available_yet'] = 'No questions have been set up yet';
 $string['non_anonymous'] = 'User\'s name will be logged and shown with answers';
-$string['non_anonymous_entries'] = 'non anonymous entries';
-$string['non_respondents_students'] = 'non respondents students';
-$string['notavailable'] = 'this feedback is not available';
+$string['non_anonymous_entries'] = 'Non anonymous entries ({$a})';
+$string['non_respondents_students'] = 'Non respondents students ({$a})';
 $string['not_completed_yet'] = 'Not completed yet';
-$string['not_started'] = 'not started';
+$string['not_started'] = 'Not started';
 $string['no_templates_available_yet'] = 'No templates available yet';
 $string['not_selected'] = 'Not selected';
+$string['numberoutofrange'] = 'Number out of range';
 $string['numeric'] = 'Numeric answer';
 $string['numeric_range_from'] = 'Range from';
 $string['numeric_range_to'] = 'Range to';
@@ -203,32 +207,32 @@ $string['of'] = 'of';
 $string['oldvaluespreserved'] = 'All old questions and the assigned values will be preserved';
 $string['oldvalueswillbedeleted'] = 'Current questions and all responses will be deleted.';
 $string['only_one_captcha_allowed'] = 'Only one captcha is allowed in a feedback';
+$string['openafterclose'] = 'You have specified an open date after the close date';
 $string['overview'] = 'Overview';
 $string['page'] = 'Page';
 $string['page-mod-feedback-x'] = 'Any feedback module page';
 $string['page_after_submit'] = 'Completion message';
 $string['pagebreak'] = 'Page break';
-$string['parameters_missing'] = 'Parameters missing from';
-$string['picture'] = 'Picture';
-$string['picture_file_list'] = 'List of pictures';
-$string['picture_values'] = 'Choose one or more<br />picture files from the list:';
 $string['pluginadministration'] = 'Feedback administration';
 $string['pluginname'] = 'Feedback';
 $string['position'] = 'Position';
-$string['preview'] = 'Preview';
-$string['preview_help'] = 'In the preview you can change the order of questions.';
 $string['previous_page'] = 'Previous page';
+$string['privacy:metadata:completed'] = 'A record of the submissions to the feedback';
+$string['privacy:metadata:completed:anonymousresponse'] = 'Whether the submission is to be used anonymously.';
+$string['privacy:metadata:completed:timemodified'] = 'The time when the submission was last modified.';
+$string['privacy:metadata:completed:userid'] = 'The ID of the user who completed the feedback activity.';
+$string['privacy:metadata:completedtmp'] = 'A record of the submissions which are still in progress.';
+$string['privacy:metadata:value'] = 'A record of the answer to a question.';
+$string['privacy:metadata:value:value'] = 'The chosen answer.';
+$string['privacy:metadata:valuetmp'] = 'A record of the answer to a question in a submission in progress.';
 $string['public'] = 'Public';
 $string['question'] = 'Question';
 $string['questionandsubmission'] = 'Question and submission settings';
 $string['questions'] = 'Questions';
+$string['questionslimited'] = 'Showing only {$a} first questions, view individual answers or download table data to view all.';
 $string['radio'] = 'Multiple choice - single answer';
-$string['radiobutton'] = 'Multiple choice - single answer allowed (radio buttons)';
-$string['radiobutton_rated'] = 'Radiobutton (rated)';
-$string['radiorated'] = 'Radiobutton (rated)';
 $string['radio_values'] = 'Responses';
 $string['ready_feedbacks'] = 'Ready feedbacks';
-$string['relateditemsdeleted'] = 'All responses for this question will also be deleted.';
 $string['required'] = 'Required';
 $string['resetting_data'] = 'Reset feedback responses';
 $string['resetting_feedbacks'] = 'Resetting feedbacks';
@@ -240,15 +244,13 @@ $string['save_as_new_template'] = 'Save as new template';
 $string['save_entries'] = 'Submit your answers';
 $string['save_item'] = 'Save question';
 $string['saving_failed'] = 'Saving failed';
-$string['saving_failed_because_missing_or_false_values'] = 'Saving failed because missing or false values';
+$string['search:activity'] = 'Feedback - activity information';
 $string['search_course'] = 'Search course';
 $string['searchcourses'] = 'Search courses';
 $string['searchcourses_help'] = 'Search for the code or name of the course(s) that you wish to associate with this feedback.';
 $string['selected_dump'] = 'Selected indexes of $SESSION variable are dumped below:';
 $string['send'] = 'send';
 $string['send_message'] = 'send message';
-$string['separator_decimal'] = '.';
-$string['separator_thousand'] = ',';
 $string['show_all'] = 'Show all';
 $string['show_analysepage_after_submit'] = 'Show analysis page';
 $string['show_entries'] = 'Show responses';
@@ -256,15 +258,14 @@ $string['show_entry'] = 'Show response';
 $string['show_nonrespondents'] = 'Show non-respondents';
 $string['site_after_submit'] = 'Site after submit';
 $string['sort_by_course'] = 'Sort by course';
-$string['start'] = 'Start';
-$string['started'] = 'started';
-$string['stop'] = 'End';
+$string['started'] = 'Started';
+$string['startedon'] = 'Started on {$a}';
 $string['subject'] = 'Subject';
-$string['switch_group'] = 'Switch group';
-$string['switch_item_to_not_required'] = 'switch to: answer not required';
-$string['switch_item_to_required'] = 'switch to: answer required';
+$string['switch_item_to_not_required'] = 'Set as not required';
+$string['switch_item_to_required'] = 'Set as required';
 $string['template'] = 'Template';
 $string['templates'] = 'Templates';
+$string['template_deleted'] = 'Template deleted';
 $string['template_saved'] = 'Template saved';
 $string['textarea'] = 'Longer text answer';
 $string['textarea_height'] = 'Number of lines';
@@ -278,12 +279,39 @@ $string['typemissing'] = 'missing value "type"';
 $string['update_item'] = 'Save changes to question';
 $string['url_for_continue'] = 'Link to next activity';
 $string['url_for_continue_help'] = 'After submitting the feedback, a continue button is displayed, which links to the course page. Alternatively, it may link to the next activity if the URL of the activity is entered here.';
-$string['use_one_line_for_each_value'] = '<br />Use one line for each answer!';
+$string['use_one_line_for_each_value'] = 'Use one line for each answer!';
 $string['use_this_template'] = 'Use this template';
 $string['using_templates'] = 'Use a template';
 $string['vertical'] = 'vertical';
+// Deprecated since Moodle 3.1.
+$string['cannotmapfeedback'] = 'Database problem, unable to map feedback to course';
+$string['line_values'] = 'Rating';
+$string['mapcourses_help'] = 'Once you have selected the relevant course(s) from your search,
+you can associate them with this feedback using map course(s). Multiple courses may be selected by holding down the Apple or Ctrl key whilst clicking on the course names. A course may be disassociated from a feedback at any time.';
+$string['max_args_exceeded'] = 'Max 6 arguments can be handled, too many arguments for';
+$string['cancel_moving'] = 'Cancel moving';
+$string['movedown_item'] = 'Move this question down';
+$string['move_here'] = 'Move here';
+$string['moveup_item'] = 'Move this question up';
+$string['notavailable'] = 'this feedback is not available';
+$string['saving_failed_because_missing_or_false_values'] = 'Saving failed because missing or false values';
+$string['cannotunmap'] = 'Database problem, unable to unmap';
 $string['viewcompleted'] = 'completed feedbacks';
 $string['viewcompleted_help'] = 'You may view completed feedback forms, searchable by course and/or by question.
 Feedback responses may be exported to Excel.';
-// Deprecated since Moodle 3.0.
-$string['completed'] = 'completed';
+$string['parameters_missing'] = 'Parameters missing from';
+$string['picture'] = 'Picture';
+$string['picture_file_list'] = 'List of pictures';
+$string['picture_values'] = 'Choose one or more<br />picture files from the list:';
+$string['preview'] = 'Preview';
+$string['preview_help'] = 'In the preview you can change the order of questions.';
+$string['switch_group'] = 'Switch group';
+$string['separator_decimal'] = '.';
+$string['separator_thousand'] = ',';
+$string['relateditemsdeleted'] = 'All responses for this question will also be deleted.';
+$string['radiorated'] = 'Radiobutton (rated)';
+$string['radiobutton'] = 'Multiple choice - single answer allowed (radio buttons)';
+$string['radiobutton_rated'] = 'Radiobutton (rated)';
+// Deprecated since Moodle 3.2.
+$string['start'] = 'Start';
+$string['stop'] = 'End';
