@@ -62,7 +62,12 @@ function label_add_instance($label) {
     $label->name = get_label_name($label);
     $label->timemodified = time();
 
-    return $DB->insert_record("label", $label);
+    $id = $DB->insert_record("label", $label);
+
+    $completiontimeexpected = !empty($label->completionexpected) ? $label->completionexpected : null;
+    \core_completion\api::update_completion_date_event($label->coursemodule, 'label', $id, $completiontimeexpected);
+
+    return $id;
 }
 
 /**
@@ -81,6 +86,9 @@ function label_update_instance($label) {
     $label->timemodified = time();
     $label->id = $label->instance;
 
+    $completiontimeexpected = !empty($label->completionexpected) ? $label->completionexpected : null;
+    \core_completion\api::update_completion_date_event($label->coursemodule, 'label', $label->id, $completiontimeexpected);
+
     return $DB->update_record("label", $label);
 }
 
@@ -102,6 +110,9 @@ function label_delete_instance($id) {
 
     $result = true;
 
+    $cm = get_coursemodule_from_instance('label', $id);
+    \core_completion\api::update_completion_date_event($cm->id, 'label', $label->id, null);
+
     if (! $DB->delete_records("label", array("id"=>$label->id))) {
         $result = false;
     }
@@ -145,6 +156,10 @@ function label_get_coursemodule_info($coursemodule) {
  * @return array status array
  */
 function label_reset_userdata($data) {
+
+    // Any changes to the list of dates that needs to be rolled should be same during course restore and course reset.
+    // See MDL-9367.
+
     return array();
 }
 
@@ -324,3 +339,47 @@ function label_generate_resized_image(stored_file $file, $maxwidth, $maxheight)
         return $img;
     }
 }
+
+/**
+ * Check if the module has any update that affects the current user since a given time.
+ *
+ * @param  cm_info $cm course module data
+ * @param  int $from the time to check updates from
+ * @param  array $filter  if we need to check only specific updates
+ * @return stdClass an object with the different type of areas indicating if they were updated or not
+ * @since Moodle 3.2
+ */
+function label_check_updates_since(cm_info $cm, $from, $filter = array()) {
+    $updates = course_check_module_updates_since($cm, $from, array(), $filter);
+    return $updates;
+}
+
+/**
+ * This function receives a calendar event and returns the action associated with it, or null if there is none.
+ *
+ * This is used by block_myoverview in order to display the event appropriately. If null is returned then the event
+ * is not displayed on the block.
+ *
+ * @param calendar_event $event
+ * @param \core_calendar\action_factory $factory
+ * @return \core_calendar\local\event\entities\action_interface|null
+ */
+function mod_label_core_calendar_provide_event_action(calendar_event $event,
+                                                      \core_calendar\action_factory $factory) {
+    $cm = get_fast_modinfo($event->courseid)->instances['label'][$event->instance];
+
+    $completion = new \completion_info($cm->get_course());
+
+    $completiondata = $completion->get_data($cm, false);
+
+    if ($completiondata->completionstate != COMPLETION_INCOMPLETE) {
+        return null;
+    }
+
+    return $factory->create_instance(
+        get_string('view'),
+        new \moodle_url('/mod/label/view.php', ['id' => $cm->id]),
+        1,
+        true
+    );
+}
