@@ -17,13 +17,14 @@
 /**
  * Quiz responses report version information.
  *
- * @package    quiz
- * @subpackage responses
- * @copyright  2011 Tim Hunt
- * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package   quiz_responses
+ * @copyright 2011 Tim Hunt
+ * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
 
 defined('MOODLE_INTERNAL') || die();
 
-$plugin->version  = 2011051200;
-$plugin->requires = 2011060313;
+$plugin->version  = 2017111300;
+$plugin->requires = 2017110800;
+$plugin->component = 'quiz_responses';
+
