@@ -31,10 +31,10 @@ $string['allocationdone'] = 'Allocation done';
 $string['allocationerror'] = 'Allocation error';
 $string['allocationconfigured'] = 'Allocation configured';
 $string['allowedfiletypesforoverallfeedback'] = 'Feedback attachment allowed file types';
-$string['allowedfiletypesforoverallfeedback_help'] = 'Feedback attachment allowed file types can be restricted by entering a comma-separated list of file extensions, for example \'mp4, mp3, png, jpg\'. If the field is left empty, then all file types are allowed.';
+$string['allowedfiletypesforoverallfeedback_help'] = 'Feedback attachment file types can be restricted by providing a list of allowed file types. If the field is left empty, then all file types are allowed.';
 $string['allowedfiletypesforoverallfeedback_link'] = 'admin/tool/filetypes/index';
 $string['allowedfiletypesforsubmission'] = 'Submission attachment allowed file types';
-$string['allowedfiletypesforsubmission_help'] = 'Submission attachment allowed file types can be restricted by entering a comma-separated list of file extensions, for example \'mp4, mp3, png, jpg\'. If the field is left empty, then all file types are allowed.';
+$string['allowedfiletypesforsubmission_help'] = 'Submission attachment file types can be restricted by providing a list of allowed file types. If the field is left empty, then all file types are allowed.';
 $string['allowedfiletypesforsubmission_link'] = 'admin/tool/filetypes/index';
 $string['allsubmissions'] = 'All submissions ({$a})';
 $string['alreadygraded'] = 'Already graded';
@@ -57,16 +57,17 @@ $string['assessmentbyyourself'] = 'Your assessment';
 $string['assessmentdeleted'] = 'Assessment deallocated';
 $string['assessmentend'] = 'Deadline for assessment';
 $string['assessmentendbeforestart'] = 'Deadline for assessment can not be specified before the open for assessment date';
-$string['assessmentendevent'] = '{$a} (assessment deadline)';
+$string['assessmentendevent'] = '{$a} deadline for assessment';
 $string['assessmentenddatetime'] = 'Assessment deadline: {$a->daydatetime} ({$a->distanceday})';
 $string['assessmentform'] = 'Assessment form';
 $string['assessmentofsubmission'] = '<a href="{$a->assessmenturl}">Assessment</a> of <a href="{$a->submissionurl}">{$a->submissiontitle}</a>';
 $string['assessmentreference'] = 'Reference assessment';
 $string['assessmentreferenceconflict'] = 'It is not possible to assess an example submission for which you provided a reference assessment.';
 $string['assessmentreferenceneeded'] = 'You have to assess this example submission to provide a reference assessment. Click \'Continue\' button to assess the submission.';
+$string['assessments'] = 'Assessments';
 $string['assessmentsettings'] = 'Assessment settings';
 $string['assessmentstart'] = 'Open for assessment from';
-$string['assessmentstartevent'] = '{$a} (opens for assessment)';
+$string['assessmentstartevent'] = '{$a} opens for assessment';
 $string['assessmentstartdatetime'] = 'Open for assessment from {$a->daydatetime} ({$a->distanceday})';
 $string['assessmentweight'] = 'Assessment weight';
 $string['assignedassessments'] = 'Assigned submissions to assess';
@@ -107,8 +108,6 @@ $string['editingsubmission'] = 'Editing submission';
 $string['editsubmission'] = 'Edit submission';
 $string['err_multiplesubmissions'] = 'While editing this form, another version of the submission has been saved. Multiple submissions per user are not allowed.';
 $string['err_removegrademappings'] = 'Unable to remove the unused grade mappings';
-$string['err_unknownfileextension'] = 'Unknown file extension: {$a}';
-$string['err_wrongfileextension'] = 'Some files ({$a->wrongfiles}) cannot be uploaded. Only file types {$a->whitelist} are allowed.';
 $string['evaluategradeswait'] = 'Please wait until the assessments are evaluated and the grades are calculated';
 $string['evaluation'] = 'Grading evaluation';
 $string['evaluationmethod'] = 'Grading evaluation method';
@@ -177,6 +176,10 @@ $string['gradingsettings'] = 'Grading settings';
 $string['groupnoallowed'] = 'You are not allowed to access any group in this workshop';
 $string['chooseuser'] = 'Choose user...';
 $string['iamsure'] = 'Yes, I am sure';
+$string['indicator:cognitivedepth'] = 'Workshop cognitive';
+$string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Workshop activity.';
+$string['indicator:socialbreadth'] = 'Workshop social';
+$string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Workshop activity.';
 $string['info'] = 'Info';
 $string['instructauthors'] = 'Instructions for submission';
 $string['instructreviewers'] = 'Instructions for assessment';
@@ -196,6 +199,7 @@ Submissions are assessed using a multi-criteria assessment form defined by the t
 Students obtain two grades in a workshop activity - a grade for their submission and a grade for their assessment of their peers\' submissions. Both grades are recorded in the gradebook.';
 $string['modulename_link'] = 'mod/workshop/view';
 $string['modulenameplural'] = 'Workshops';
+$string['myassessments'] = 'My assessments';
 $string['mysubmission'] = 'My submission';
 $string['nattachments'] = 'Maximum number of submission attachments';
 $string['noexamples'] = 'No examples yet in this workshop';
@@ -232,6 +236,46 @@ $string['pluginadministration'] = 'Workshop administration';
 $string['pluginname'] = 'Workshop';
 $string['prepareexamples'] = 'Prepare example submissions';
 $string['previewassessmentform'] = 'Preview';
+$string['privacy:metadata:aggregatedgradinggrade'] = 'Aggregated grade for all assessments made by the user in the given workshop activity';
+$string['privacy:metadata:assessmentgrade'] = 'Aggregated grade for the submission suggested by this assessment';
+$string['privacy:metadata:assessmentgradinggrade'] = 'Grade for providing this assessment';
+$string['privacy:metadata:assessmentgradinggradeover'] = 'Manually overridden value of the grade for providing this assessment';
+$string['privacy:metadata:assessmentid'] = 'Identifier of the assessment';
+$string['privacy:metadata:authorid'] = 'Identifier of the submission author';
+$string['privacy:metadata:dimensiongrade'] = 'Grade in the given assessment dimension';
+$string['privacy:metadata:dimensionid'] = 'Identifier of the assessment dimension';
+$string['privacy:metadata:example'] = 'Whether this record represents an example submission';
+$string['privacy:metadata:feedbackauthor'] = 'Feedback for the author';
+$string['privacy:metadata:feedbackauthorformat'] = 'Text format of the feedback for the author';
+$string['privacy:metadata:feedbackreviewer'] = 'Feedback for the user providing the assessment';
+$string['privacy:metadata:feedbackreviewerformat'] = 'Text format of the feedback for the user providing the assessment';
+$string['privacy:metadata:late'] = 'Whether the submission been submitted after the deadline';
+$string['privacy:metadata:peercomment'] = 'Comment on the given grade by the user providing the assessment';
+$string['privacy:metadata:peercommentformat'] = 'Text format of the comment on the given grade';
+$string['privacy:metadata:preference:perpage'] = 'Number of submissions the user prefers to see on one page';
+$string['privacy:metadata:published'] = 'Whether the submission should be published to all participants once the workshop is closed';
+$string['privacy:metadata:reviewerid'] = 'Identifier of the user providing the assessment';
+$string['privacy:metadata:strategy'] = 'Name of the grading strategy subplugin interpreting the record values';
+$string['privacy:metadata:submissioncontent'] = 'Content of the submission';
+$string['privacy:metadata:submissioncontentformat'] = 'Text format of the submission content';
+$string['privacy:metadata:submissiongrade'] = 'Aggregated grade for the submission written as a decimal number from interval 0..100';
+$string['privacy:metadata:submissiongradeover'] = 'Manually overridden value of the aggregated grade';
+$string['privacy:metadata:submissionid'] = 'Identifier of the submission';
+$string['privacy:metadata:submissiontitle'] = 'Title of the submission';
+$string['privacy:metadata:subsystem:corefiles'] = 'Workshop module stores files embedded in / attached to the submission text';
+$string['privacy:metadata:subsystem:coreplagiarism'] = 'Workshop module has inbuilt support for plagiarism prevention systems';
+$string['privacy:metadata:timeaggregated'] = 'When the aggregated grade was last calculated';
+$string['privacy:metadata:timecreated'] = 'When this record was created in the database';
+$string['privacy:metadata:timemodified'] = 'When this record was last modified in the database';
+$string['privacy:metadata:userid'] = 'Identifier of the user for which aggregated grade is calculated';
+$string['privacy:metadata:weight'] = 'Weight of the assessment';
+$string['privacy:metadata:workshopaggregations'] = 'Holds aggregated grades for assessment';
+$string['privacy:metadata:workshopassessments'] = 'Holds information about allocated assessments of workshop module submissions';
+$string['privacy:metadata:workshopgrades'] = 'Holds information about how the assessment forms were filled with grades and comments';
+$string['privacy:metadata:workshopid'] = 'Identifier of the workshop activity';
+$string['privacy:metadata:workshopsubmissions'] = 'Holds information about workshop module submissions';
+$string['privacy:request:delete:title'] = '[Deleted]';
+$string['privacy:request:delete:content'] = 'The content has been deleted at the request of the user.';
 $string['publishedsubmissions'] = 'Published submissions';
 $string['publishsubmission'] = 'Publish submission';
 $string['publishsubmission_help'] = 'Published submissions are available to the others when the workshop is closed.';
@@ -272,7 +316,7 @@ $string['submissiondeleteconfirm'] = 'Are you sure you want to delete the follow
 $string['submissiondeleteconfirmassess'] = 'Are you sure you want to delete the following submission? Note this will also delete {$a->count} assessments associated with this submission, which may affect the reviewers\' grades.';
 $string['submissionend'] = 'Submissions deadline';
 $string['submissionendbeforestart'] = 'Submissions deadline can not be specified before the open for submissions date';
-$string['submissionendevent'] = '{$a} (submissions deadline)';
+$string['submissionendevent'] = '{$a} deadline for submissions';
 $string['submissionenddatetime'] = 'Submissions deadline: {$a->daydatetime} ({$a->distanceday})';
 $string['submissionendswitch'] = 'Switch to the next phase after the submissions deadline';
 $string['submissionendswitch_help'] = 'If the submissions deadline is specified and this box is checked, the workshop will automatically switch to the assessment phase after the submissions deadline.
@@ -282,9 +326,11 @@ $string['submissiongrade'] = 'Grade for submission';
 $string['submissiongrade_help'] = 'This setting specifies the maximum grade that may be obtained for submitted work.';
 $string['submissiongradeof'] = 'Grade for submission (of {$a})';
 $string['submissionlastmodified'] = 'Last modified';
+$string['submissionrequiredcontent'] = 'You need to enter some text or add a file.';
+$string['submissionrequiredfile'] = 'You need to add a file or enter some text.';
 $string['submissionsettings'] = 'Submission settings';
 $string['submissionstart'] = 'Open for submissions from';
-$string['submissionstartevent'] = '{$a} (opens for submissions)';
+$string['submissionstartevent'] = '{$a} opens for submissions';
 $string['submissionstartdatetime'] = 'Open for submissions from {$a->daydatetime} ({$a->distanceday})';
 $string['submissiontitle'] = 'Title';
 $string['submissionsreport'] = 'Workshop submissions report';
@@ -297,12 +343,18 @@ $string['subplugintype_workshopform'] = 'Grading strategy';
 $string['subplugintype_workshopform_plural'] = 'Grading strategies';
 $string['switchingphase'] = 'Switching phase';
 $string['switchphase'] = 'Switch phase';
+$string['switchphaseauto'] = 'Switching has been scheduled';
 $string['switchphasenext'] = 'Switch to the next phase';
+$string['switchphase10'] = 'Switch to the setup phase';
 $string['switchphase10info'] = 'You are about to switch the workshop into the <strong>Setup phase</strong>. In this phase, users cannot modify their submissions or their assessments. Teachers may use this phase to change workshop settings, modify the grading strategy or tweak assessment forms.';
+$string['switchphase20'] = 'Switch to the submission phase';
 $string['switchphase20info'] = 'You are about to switch the workshop into the <strong>Submission phase</strong>. Students may submit their work during this phase (within the submission access control dates, if set). Teachers may allocate submissions for peer review.';
+$string['switchphase30'] = 'Switch to the assessment phase';
 $string['switchphase30auto'] = 'Workshop will automatically switch into the assessment phase after {$a->daydatetime} ({$a->distanceday})';
 $string['switchphase30info'] = 'You are about to switch the workshop into the <strong>Assessment phase</strong>. In this phase, reviewers may assess the submissions they have been allocated (within the assessment access control dates, if set).';
+$string['switchphase40'] = 'Switch to the evaluation phase';
 $string['switchphase40info'] = 'You are about to switch the workshop into the <strong>Grading evaluation phase</strong>. In this phase, users cannot modify their submissions or their assessments. Teachers may use the grading evaluation tools to calculate final grades and provide feedback for reviewers.';
+$string['switchphase50'] = 'Close workshop';
 $string['switchphase50info'] = 'You are about to close the workshop. This will result in the calculated grades appearing in the gradebook. Students may view their submissions and their submission assessments.';
 $string['taskassesspeers'] = 'Assess peers';
 $string['taskassesspeersdetails'] = 'total: {$a->total}<br />pending: {$a->todo}';
@@ -334,6 +386,7 @@ $string['userplanaccessibilitytitle'] = 'Workshop timeline with {$a} phases';
 $string['useselfassessment'] = 'Use self-assessment';
 $string['useselfassessment_help'] = 'If enabled, a user may be allocated their own submission to assess and will receive a grade for assessment in addition to a grade for their submission.';
 $string['useselfassessment_desc'] = 'Students may assess their own work';
+$string['viewworkshopsummary'] = 'View workshop summary';
 $string['weightinfo'] = 'Weight: {$a}';
 $string['withoutsubmission'] = 'Reviewer without own submission';
 $string['workshop:addinstance'] = 'Add a new workshop';
@@ -362,3 +415,7 @@ $string['yoursubmission'] = 'Your submission';
 
 // Deprecated since Moodle 3.1.
 $string['yourassessment'] = 'Your assessment';
+
+// Deprecated since Moodle 3.4.
+$string['err_unknownfileextension'] = 'Unknown file extension: {$a}';
+$string['err_wrongfileextension'] = 'Some files ({$a->wrongfiles}) cannot be uploaded. Only file types {$a->whitelist} are allowed.';
